@@ -6,7 +6,7 @@ from pyLearnAlgorithms.polynomial_regression import PolynomialRegression
 class GraphView():
     """graphic display class of machine learning models"""
 
-    def __init__(self, X, y):
+    def __init__(self, X = np.array([]), y = np.array([])):
         """stores predictive attributes and labels"""
 
         # predictive attributes
@@ -70,7 +70,7 @@ class GraphView():
         X_poly -= mu
         X_poly /= sigma
         X_poly = np.concatenate([np.ones((x.shape[0], 1)), X_poly], axis=1)
-        optimized_values = model_poly.trainLinearReg(polynomial_degree, lambda_, maxiter)
+        optimized_values = model_poly.trainPolyReg(polynomial_degree, lambda_, maxiter)
         plt.figure(figsize = (10, 5))
         plt.plot(self.X, self.y, 'ro', ms=10, mew=1.5, mec='k')
         plt.plot(x, np.dot(X_poly, optimized_values.x), '--', lw=2)
@@ -113,7 +113,6 @@ class GraphView():
         plt.figure(figsize = (10,5))
         plt.scatter(Xtest, ytest, label = 'correct values')
         plt.scatter( Xtest, pred, label = 'predict values')
-
         plt.legend()
         plt.grid(True)
         plt.box(False)
@@ -121,6 +120,27 @@ class GraphView():
 
         return None
 
+    def visualize_image(self, image_array, figsize = (20,6), box = False, title = ''):
+        """method for viewing images"""
+        
+        plt.figure(figsize = figsize)
+        plt.imshow(image_array)
+        plt.box(box)
+        plt.title(title)
+
+        return None
+    
+    def visualize_benford_law(self, list_prob):
+        """method for visualizing the benford curve in images"""
+        
+        plt.figure(figsize = (10, 5))
+        plt.plot([1,2,3,4,5,6,7,8,9], list_prob, '-o')
+        plt.title("Benford's Law")
+        plt.grid(True)
+        plt.box(False)
+
+        return None
+
     
     
 
