@@ -49,7 +49,7 @@ class PolynomialRegression():
 
         return X_poly
 
-    def trainLinearReg(self, polynomial_degree, lambda_ = 0.0, maxiter = 200):
+    def trainPolyReg(self, polynomial_degree, lambda_ = 0.0, maxiter = 200):
         """training the model for minimizing the cost function and modifying theta parameters"""
 
         model_poly = PolynomialRegression(self.X, self.y)
@@ -71,9 +71,9 @@ class PolynomialRegression():
         error_train = np.zeros(m)
         error_val   = np.zeros(m)
         for i in range(1, m + 1):
-            teta_t = self.__trainLinearReg(X_poly[:i], y[:i], lambda_)
-            error_train[i-1],_=self.__linearRegCostFunction(X_poly[:i], y[:i],teta_t.x, lambda_)
-            error_val[i - 1], _ = self.__linearRegCostFunction(Xval, yval, teta_t.x, lambda_)
+            teta_t = self.__trainPolyReg(X_poly[:i], y[:i], lambda_)
+            error_train[i-1],_=self.__polyRegCostFunction(X_poly[:i], y[:i],teta_t.x, lambda_)
+            error_val[i - 1], _ = self.__polyRegCostFunction(Xval, yval, teta_t.x, lambda_)
             
         return error_train, error_val
     
@@ -84,21 +84,21 @@ class PolynomialRegression():
         error_val = np.zeros(len(lambda_vec))
         for i in range(len(lambda_vec)):
             lambda_try = lambda_vec[i]
-            teta_t = self.__trainLinearReg(X_poly, y, lambda_ = lambda_try)
-            error_train[i], _ = self.__linearRegCostFunction(X_poly, y, teta_t.x, lambda_ = 0)
-            error_val[i], _ = self.__linearRegCostFunction(Xval, yval, teta_t.x, lambda_ = 0)
+            teta_t = self.__trainPolyReg(X_poly, y, lambda_ = lambda_try)
+            error_train[i], _ = self.__polyRegCostFunction(X_poly, y, teta_t.x, lambda_ = 0)
+            error_val[i], _ = self.__polyRegCostFunction(Xval, yval, teta_t.x, lambda_ = 0)
 
         return lambda_vec, error_train, error_val
     
     def predict(self, Xtest, X_poly, y, lambda_ = 0.0):
         """makes the prediction for the test values"""
 
-        teta_t = self.__trainLinearReg(X_poly, y, lambda_)
+        teta_t = self.__trainPolyReg(X_poly, y, lambda_)
         pred = np.dot(Xtest, teta_t.x)
 
         return pred 
     
-    def __linearRegCostFunction(self, X, y, theta = [1,1], lambda_= 0.0):
+    def __polyRegCostFunction(self, X, y, theta = [1,1], lambda_= 0.0):
         """cost function for a varied hypothesis (with regularization)"""
 
         theta = np.array(theta)
@@ -112,11 +112,11 @@ class PolynomialRegression():
 
         return J, grad
     
-    def __trainLinearReg(self,X, y, lambda_ = 0.0, maxiter = 200):
+    def __trainPolyReg(self,X, y, lambda_ = 0.0, maxiter = 200):
         """training the model for minimizing the cost function and modifying theta parameters"""
 
         theta = np.zeros(X.shape[1])
-        costFunction = lambda t: self.__linearRegCostFunction(X, y, t, lambda_)
+        costFunction = lambda t: self.__polyRegCostFunction(X, y, t, lambda_)
         options = {'maxiter': maxiter}
         res = optimize.minimize(costFunction,theta,jac=True,method='TNC',options=options)
 
