@@ -1,5 +1,5 @@
 import sys
-sys.path.append('../MachineLearningPackage/')
+sys.path.append('../pyLearnAlgorithms/')
 
 from pyLearnAlgorithms.load_data import LoadData
 
