@@ -1,8 +1,8 @@
 import sys
-sys.path.append('../MachineLearningPackage/')
+sys.path.append('../pyLearnAlgorithms/')
 
-from pylearn.treat_data.load_data import LoadData
-from pylearn.treat_data.split_data import SplitData
+from pyLearnAlgorithms.load_data import LoadData
+from pyLearnAlgorithms.split_data import SplitData
 
 matlab_file = LoadData('tests/datasets', 'WaterLevel.mat')
 
